/*
    This software may only be used by you under license from AT&T Corp.
    ("AT&T").  A copy of AT&T's Source Code Agreement is available at
    AT&T's Internet website having the URL:
    <http://www.research.att.com/sw/tools/graphviz/license/source.html>
    If you received this software without first entering into a license
    with AT&T, you have an infringing copy of this software and cannot use
    it without violating AT&T's intellectual property rights.
*/

#ifndef         NEATO_H
#define         NEATO_H
#ifdef _PACKAGE_AST
#include <ast.h>
#endif

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include	"pathplan.h"
#include	"render.h"
#include	"neatoprocs.h"
#include	"adjust.h"

#endif /* NEATO_H */
